mirror of
https://github.com/karpathy/llm.c.git
synced 2026-07-27 20:25:09 -04:00
Remove warp size - moved to common.h
This commit is contained in:
parent
09910acc0b
commit
d003274b7c
1 changed files with 0 additions and 2 deletions
|
|
@ -874,7 +874,6 @@ __global__ void layernorm_backward_kernel9(floatX* dinp, floatX* dweight, floatX
|
|||
}
|
||||
__trap(); // prefer to crash here than run into a deadlock later on
|
||||
}
|
||||
constexpr int WARP_SIZE = 32;
|
||||
int BLOCK_SIZE = blockDim.x;
|
||||
int warpsInBlock = BLOCK_SIZE / WARP_SIZE; //number of warps in block
|
||||
extern __shared__ float shared[]; // size = 2 * C + 1
|
||||
|
|
@ -1059,7 +1058,6 @@ layernorm_backward_kernel10(floatX* dinp, floatX* dweight, floatX* dbias, float*
|
|||
const floatX* dout, const floatX* inp, const floatX* weight,
|
||||
const floatX* mean, const floatX* rstd,
|
||||
int B, int T, int C) {
|
||||
constexpr int WARP_SIZE = 32;
|
||||
int BLOCK_SIZE = blockDim.x;
|
||||
int warpsInBlock = BLOCK_SIZE / WARP_SIZE; //number of warps in block
|
||||
extern __shared__ float shared[]; // size = 2 * C + 1
|
||||
|
|
|
|||
Loading…
Add table
Add a link
Reference in a new issue